from typing import List, Optional

from sqlalchemy.orm import Session

from app.database.crud_base import CRUDBase
from app.models.item import Item
from app.schemas.item import ItemCreate, ItemUpdate


class CRUDItem(CRUDBase[Item, ItemCreate, ItemUpdate]):
    def get_by_name(self, db: Session, *, name: str) -> Optional[Item]:
        return db.query(Item).filter(Item.name == name).first()

    def get_multi_by_active(
        self, db: Session, *, active: bool, skip: int = 0, limit: int = 100
    ) -> List[Item]:
        return (
            db.query(Item)
            .filter(Item.is_active == active)
            .offset(skip)
            .limit(limit)
            .all()
        )


item = CRUDItem(Item)